==> jc-1.4.0.tar.gz: java/lang/Boolean.h <==
// public final class java.lang.Boolean

// class file dependencies
// @dep_class 52a05cb5e85a24ee java_lang_Boolean
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Boolean_H_
#define _JC_java_lang_Boolean_H_

// Forward structure declarations
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_Boolean$sub_refs	_jc_java_lang_Boolean$sub_refs;
typedef struct _jc_java_lang_Boolean$sub_nonrefs	_jc_java_lang_Boolean$sub_nonrefs;
typedef struct _jc_java_lang_Boolean$refs	_jc_java_lang_Boolean$refs;
typedef struct _jc_java_lang_Boolean$nonrefs	_jc_java_lang_Boolean$nonrefs;
typedef struct _jc_java_lang_Boolean$object	_jc_java_lang_Boolean$object;

typedef struct _jc_java_lang_Boolean$fields_struct	_jc_java_lang_Boolean$fields_struct;
typedef const struct _jc_java_lang_Boolean$vmethods	_jc_java_lang_Boolean$vmethods;
typedef const struct _jc_java_lang_Boolean$vtable	_jc_java_lang_Boolean$vtable;
typedef const struct _jc_java_lang_Boolean$vtype	_jc_java_lang_Boolean$vtype;

// Class fields structure
struct _jc_java_lang_Boolean$fields_struct {
	struct _jc_java_lang_Boolean$object	*FALSE;
	struct _jc_java_lang_Boolean$object	*TRUE;
	struct _jc_java_lang_Class$object	*TYPE;
	jlong	serialVersionUID;
};
extern _jc_java_lang_Boolean$fields_struct _jc_java_lang_Boolean$class_fields;

// Constructors
extern void _jc_java_lang_Boolean$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_Boolean$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_Boolean$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_java_lang_Boolean$object *, jboolean);

// Virtual methods
extern jboolean _jc_java_lang_Boolean$method$booleanValue$b4f083df16d4b97f(_jc_env *, struct _jc_java_lang_Boolean$object *);
extern jboolean _jc_java_lang_Boolean$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_Boolean$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_lang_Boolean$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_Boolean$object *);
extern struct _jc_java_lang_String$object *_jc_java_lang_Boolean$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_lang_Boolean$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_Boolean$method_info$booleanValue$b4f083df16d4b97f;
extern _jc_method _jc_java_lang_Boolean$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_Boolean$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_lang_Boolean$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_lang_Boolean$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern jboolean _jc_java_lang_Boolean$method$getBoolean$b81d04397f133bcf(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_String$object *_jc_java_lang_Boolean$method$toString$75feb72fe71c4b7f(_jc_env *, jboolean);
extern struct _jc_java_lang_Boolean$object *_jc_java_lang_Boolean$method$valueOf$eb56cc9b0cab8e8a(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Boolean$object *_jc_java_lang_Boolean$method$valueOf$b76cf313c310950f(_jc_env *, jboolean);

// Virtual methods structure
struct _jc_java_lang_Boolean$vmethods {
	jboolean	(*booleanValue$b4f083df16d4b97f)(_jc_env *, struct _jc_java_lang_Boolean$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_Boolean$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_Boolean$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_lang_Boolean$object *);
};

// Vtable
struct _jc_java_lang_Boolean$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Boolean$vmethods	java_lang_Boolean;
};

// Vtype
struct _jc_java_lang_Boolean$vtype {
	_jc_type			type;
	_jc_java_lang_Boolean$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Boolean$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Boolean$refs {
    _jc_java_lang_Boolean$sub_refs	java_lang_Boolean;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Boolean$sub_nonrefs {
	jboolean	value;
};

// Non-reference instance fields (object)
struct _jc_java_lang_Boolean$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Boolean$sub_nonrefs	java_lang_Boolean;
};

// Object instance structure
struct _jc_java_lang_Boolean$object {
	_jc_java_lang_Boolean$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Boolean$vtype	*vtype;
	_jc_java_lang_Boolean$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Boolean$vtype _jc_java_lang_Boolean$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Boolean, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Boolean$class_object;

#endif	/* _JC_java_lang_Boolean_H_ */

==> jc-1.4.6.tar.gz: java/lang/Boolean.h <==
// public final class java.lang.Boolean

// class file dependencies
// @dep_class 52a05cb5e85a24ee java_lang_Boolean
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Boolean_H_
#define _JC_java_lang_Boolean_H_

// Forward structure declarations
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_Boolean$sub_refs	_jc_java_lang_Boolean$sub_refs;
typedef struct _jc_java_lang_Boolean$sub_nonrefs	_jc_java_lang_Boolean$sub_nonrefs;
typedef struct _jc_java_lang_Boolean$refs	_jc_java_lang_Boolean$refs;
typedef struct _jc_java_lang_Boolean$nonrefs	_jc_java_lang_Boolean$nonrefs;
typedef struct _jc_java_lang_Boolean$object	_jc_java_lang_Boolean$object;

typedef struct _jc_java_lang_Boolean$fields_struct	_jc_java_lang_Boolean$fields_struct;
typedef const struct _jc_java_lang_Boolean$vmethods	_jc_java_lang_Boolean$vmethods;
typedef const struct _jc_java_lang_Boolean$vtable	_jc_java_lang_Boolean$vtable;
typedef const struct _jc_java_lang_Boolean$vtype	_jc_java_lang_Boolean$vtype;

// Class fields structure
struct _jc_java_lang_Boolean$fields_struct {
	struct _jc_java_lang_Boolean$object	*FALSE;
	struct _jc_java_lang_Boolean$object	*TRUE;
	struct _jc_java_lang_Class$object	*TYPE;
	jlong	serialVersionUID;
};
extern _jc_java_lang_Boolean$fields_struct _jc_java_lang_Boolean$class_fields;

// Constructors
extern void _jc_java_lang_Boolean$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_Boolean$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_Boolean$method$_init$f0a6314ff7de5110(_jc_env *, struct _jc_java_lang_Boolean$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_lang_Boolean$method$booleanValue$b4f083df16d4b97f(_jc_env *, struct _jc_java_lang_Boolean$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_Boolean$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_Boolean$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_Boolean$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_Boolean$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_lang_Boolean$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_lang_Boolean$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_Boolean$method_info$booleanValue$b4f083df16d4b97f;
extern _jc_method _jc_java_lang_Boolean$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_Boolean$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_lang_Boolean$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_lang_Boolean$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_Boolean$method$getBoolean$b81d04397f133bcf(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_lang_Boolean$method$toString$75feb72fe71c4b7f(_jc_env *, jboolean) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Boolean$object *_jc_java_lang_Boolean$method$valueOf$eb56cc9b0cab8e8a(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Boolean$object *_jc_java_lang_Boolean$method$valueOf$b76cf313c310950f(_jc_env *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_Boolean$vmethods {
	jboolean	(*booleanValue$b4f083df16d4b97f)(_jc_env *, struct _jc_java_lang_Boolean$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_Boolean$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_Boolean$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_lang_Boolean$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_Boolean$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Boolean$vmethods	java_lang_Boolean;
};

// Vtype
struct _jc_java_lang_Boolean$vtype {
	_jc_type			type;
	_jc_java_lang_Boolean$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Boolean$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Boolean$refs {
    _jc_java_lang_Boolean$sub_refs	java_lang_Boolean;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Boolean$sub_nonrefs {
	jboolean	value;
};

// Non-reference instance fields (object)
struct _jc_java_lang_Boolean$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Boolean$sub_nonrefs	java_lang_Boolean;
};

// Object instance structure
struct _jc_java_lang_Boolean$object {
	_jc_java_lang_Boolean$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Boolean$vtype	*vtype;
	_jc_java_lang_Boolean$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Boolean$vtype _jc_java_lang_Boolean$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Boolean, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Boolean$class_object;

#endif	/* _JC_java_lang_Boolean_H_ */
